@@ -41,7 +41,7 @@ def printVersion(ctx):
 @click.group()
 @click.option("-ak", "--accessKey", 'access_key', default="", help="access key to Testin annotation system, see: http://label.testin.cn/v/secret-key")
 @click.option("-sk", "--secretKey", 'secret_key', default="")
-@click.option("-h", "--host", 'host', default="https://label.testin.cn/", help="domain name that access to annotation system you would like to operate, default will be: https://label.testin.cn/")
+@click.option("-h", "--host", 'host', default="http://label.testin.cn/", help="domain name that access to annotation system you would like to operate, default will be: https://label.testin.cn/")
 @click.option('--debug/--no-debug', default=True, help="using debug mod or not, default is False")
 @click.pass_context
 def main(ctx, access_key, secret_key, host, debug):
@@ -134,14 +134,13 @@ def export(ctx, file):
         if scriptPath == "":
             scriptPath = os.path.abspath('.')
         sys.path.append(scriptPath)
-        print(sys.path)
         from export import Export
         ex = Export(ctx.obj)
-        ex.exec()
     except Exception as e:
         print(e)
         raise Exception(f"can't import Export")
 
+    ex.exec()
     click.echo("done!")
 
 @main.command()
@@ -155,7 +154,7 @@ def version(ctx):
 @main.command()
 @click.option("-ak", "--accessKey", 'access_key', default="", help="access key to Testin annotation system, see: http://label.testin.cn/v/secret-key")
 @click.option("-sk", "--secretKey", 'secret_key', default="")
-@click.option("-h", "--host", 'host', default="https://label.testin.cn/", help="domain name that access to annotation system you would like to operate, default will be: https://label.testin.cn/")
+@click.option("-h", "--host", 'host', default="http://label.testin.cn/", help="domain name that access to annotation system you would like to operate, default will be: https://label.testin.cn/")
 def config(access_key, secret_key, host):
     """ setting your account """
     configFile = account._config_filepath()
