@@ -4,5 +4,5 @@ from testindata.dataset.file import File
 class ExportAbstract(metaclass=ABCMeta):
 
     @abstractmethod
-    def Exec(self) -> File:pass
+    def exec(self) -> File:pass
 
